==> axon-messaging-4.4.4-sources.jar: org/axonframework/eventhandling/async/SequentialPerAggregatePolicy.java <==
/*
 * Copyright (c) 2010-2020. Axon Framework
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.axonframework.eventhandling.async;

import org.axonframework.eventhandling.DomainEventMessage;
import org.axonframework.eventhandling.EventMessage;

/**
 * Concurrency policy that requires sequential processing of events raised by the same aggregate. Events from different
 * aggregates may be processed in different threads, as will events that do not extend the DomainEvent type.
 *
 * @author Allard Buijze
 * @since 0.3
 */
public class SequentialPerAggregatePolicy implements SequencingPolicy<EventMessage> {

    private static final SequentialPerAggregatePolicy INSTANCE = new SequentialPerAggregatePolicy();

    /**
     * Return a singleton instance of the this Sequencing Policy.
     *
     * @return a singleton SequentialPerAggregatePolicy instance
     */
    public static SequentialPerAggregatePolicy instance() {
        return INSTANCE;
    }

    @Override
    public Object getSequenceIdentifierFor(EventMessage event) {
        if (event instanceof DomainEventMessage) {
            return ((DomainEventMessage) event).getAggregateIdentifier();
        }
        return null;
    }
}

==> axon-messaging-4.11.1-sources.jar: org/axonframework/eventhandling/async/SequentialPerAggregatePolicy.java <==
/*
 * Copyright (c) 2010-2022. Axon Framework
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.axonframework.eventhandling.async;

import org.axonframework.eventhandling.DomainEventMessage;
import org.axonframework.eventhandling.EventMessage;

import javax.annotation.Nonnull;

/**
 * Concurrency policy that requires sequential processing of events raised by the same aggregate. Events from different
 * aggregates may be processed in different threads, as will events that do not extend the DomainEvent type.
 *
 * @author Allard Buijze
 * @since 0.3
 */
public class SequentialPerAggregatePolicy implements SequencingPolicy<EventMessage> {

    private static final SequentialPerAggregatePolicy INSTANCE = new SequentialPerAggregatePolicy();

    /**
     * Return a singleton instance of the this Sequencing Policy.
     *
     * @return a singleton SequentialPerAggregatePolicy instance
     */
    public static SequentialPerAggregatePolicy instance() {
        return INSTANCE;
    }

    @Override
    public Object getSequenceIdentifierFor(@Nonnull EventMessage event) {
        if (event instanceof DomainEventMessage) {
            return ((DomainEventMessage) event).getAggregateIdentifier();
        }
        return null;
    }
}
